Returns (and creates on request) a per-user cache directory under
tools::R_user_dir(), suitable for passing to cache_dir in
scopus_fetch_plan(). The cache is entirely optional and can be cleared with
scopus_cache_clear().
Returns (and creates on request) a per-user cache directory under
tools::R_user_dir(), suitable for passing to cache_dir in
scopus_fetch_plan(). The cache is entirely optional and can be cleared with
scopus_cache_clear().